﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using EPiServer.Core;

namespace EPiServer.Samples
{
    public partial class RatingControl : UserControlBase
    {
        Rating _currentRating;

        /// <summary>
        /// The text to display before the rating icons
        /// </summary>
        public string InstructionText
        {
            get;
            set;
        }

        /// <summary>
        /// The text to display after the rating icons. 
        /// If the string includes a format placeholder the average value will be inserted there
        /// </summary>
        public string PostRateText
        {
            get;
            set;
        }

        protected void Page_PreRender(object sender, EventArgs e)
        {
            // Display the average rating
            PageData pageData = CurrentPage;// Obtain the PageData instance to work with   

            // Construct a PageObjectManager with the PageData
            PageObjectManager pom = new PageObjectManager(pageData);
            Rating rating = pom.Load<Rating>("Rating");

            if (_currentRating == null)
            {
                _currentRating = rating;
            }

            if (_currentRating != null)
            {
                this.AverageRatingLabel.Text = string.Format(PostRateText, _currentRating.Average.ToString());
            }
            else
            {
                // Not rated yet
                this.AverageRatingLabel.Text = string.Format(PostRateText, "0");
            }
        }

        protected void StarImage_Command(object sender, CommandEventArgs e)
        {
            // The command argument is the rating value
            int value = int.Parse(e.CommandArgument.ToString());

            // See if we already have a rating object for this page
            PageData pageData = CurrentPage;// Obtain the PageData instance to work with   

            // Construct a PageObjectManager with the PageData
            PageObjectManager pom = new PageObjectManager(pageData);
            Rating _currentRating = pom.Load<Rating>("Rating");

            if (_currentRating == null)
            {
                // No, create one
                _currentRating = new Rating();
                _currentRating.Rate(value);                
            }
            else
            {
                // Yes, update it with rating
                _currentRating.Rate(value);
            }

            // Save the rating, maintaing the same rating for every version and every language
            pom.Save("Rating", _currentRating, PageObject.OwnerOption.Page);
        }        
    }
}