﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Text;
using EPiServer.DynamicContent;
using EPiServer.Core;

namespace EPiServer.Samples
{
    /// <summary>
    /// Dynamic Content representing a rating facility for a page
    /// </summary>
    public class RatingDC : IDynamicContent
    {
        private PropertyDataCollection _props = new PropertyDataCollection();
        private const string InstructionTextKey = "Instruction Text";
        private const string PostRateTextKey = "Post Rate Text";
 
        /// <summary>
        /// Default constructor that initializes the Properties collection
        /// </summary>
        public RatingDC()
        {
            _props.Add(InstructionTextKey, new PropertyString("Rate this page"));
            _props.Add(PostRateTextKey, new PropertyString("Average rating is {0}"));
        }

        /// <summary>
        /// The text to display before the rating icons
        /// </summary>
        public string InstructionText
        {
            get
            {
                return _props[InstructionTextKey].ToString();
            }
            set
            {
                _props[InstructionTextKey].Value = value;
            }
        }

        /// <summary>
        /// The text to display after the rating icons. 
        /// If the string includes a format placeholder the average value will be inserted there
        /// </summary>
        public string PostRateText
        {
            get
            {
                return _props[PostRateTextKey].ToString();
            }
            set
            {
                _props[PostRateTextKey].Value = value;
            }
        }

        #region IDynamicContent Members

        /// <summary>
        /// The return the UI control for the rating facility
        /// </summary>
        /// <param name="hostPage"></param>
        /// <returns></returns>
        public System.Web.UI.Control GetControl(PageBase hostPage)
        {
            RatingControl control = (RatingControl)hostPage.LoadControl("~/Rating/RatingControl.ascx");
            control.InstructionText = this.InstructionText;
            control.PostRateText = this.PostRateText;
            return control;
        }

        /// <summary>
        /// Returns the properties collection for the rating facility
        /// </summary>
        public EPiServer.Core.PropertyDataCollection Properties
        {
            get
            {
                return _props;
            }
        }

        /// <summary>
        /// Throws <see cref="NotImplementedException"/>. This Dynamic Content renders with a control
        /// </summary>
        /// <param name="hostPage"></param>
        /// <returns></returns>
        public string Render(PageBase hostPage)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Returns true
        /// </summary>
        public bool RendersWithControl
        {
            get { return true; }
        }

        /// <summary>
        /// The state string for the Dynamic Content
        /// </summary>
        public string State
        {
            get
            {
                StringBuilder sb = new StringBuilder();
                sb.Append(this.InstructionText);
                sb.Append("|");
                sb.Append(this.PostRateText);
                return sb.ToString();
            }
            set
            {
                string[] values = value.Split('|');
                this.InstructionText = values[0];
                this.PostRateText = values[1];
            }
        }

        #endregion
    }
}
